# Générateur de Graphe d'État Asynchrone (Asynchronous State Graph Generator)

## Installation

Install with [pip](https://pypi.org/project/ggea/):

    pip install ggea

## Run tests

Execute the following command to run the test suite:
    
    python -m unittest tests.test
